summaryrefslogtreecommitdiffstats
path: root/generic/tclNamesp.c
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2018-06-28 21:42:54 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2018-06-28 21:42:54 (GMT)
commit5248fb06510fd1e34b13f7c4a69404ab926cf2be (patch)
tree8d4da3eb53f714af307b5c5255794d95ba0dcdff /generic/tclNamesp.c
parent94780336613da72b26e6572a616a2dfe9f087eca (diff)
downloadtcl-5248fb06510fd1e34b13f7c4a69404ab926cf2be.zip
tcl-5248fb06510fd1e34b13f7c4a69404ab926cf2be.tar.gz
tcl-5248fb06510fd1e34b13f7c4a69404ab926cf2be.tar.bz2
More API changes using size_t. Internal changes not complete yet (WIP)
Diffstat (limited to 'generic/tclNamesp.c')
-rw-r--r--generic/tclNamesp.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/generic/tclNamesp.c b/generic/tclNamesp.c
index 275e0ce..b0d4ee0 100644
--- a/generic/tclNamesp.c
+++ b/generic/tclNamesp.c
@@ -5056,7 +5056,7 @@ void
TclErrorStackResetIf(
Tcl_Interp *interp,
const char *msg,
- int length)
+ size_t length)
{
Interp *iPtr = (Interp *) interp;
@@ -5111,7 +5111,7 @@ Tcl_LogCommandInfo(
* command (must be <= command). */
const char *command, /* First character in command that generated
* the error. */
- int length) /* Number of bytes in command (-1 means use
+ size_t length) /* Number of bytes in command ((size_t)-1 means use
* all bytes up to first null byte). */
{
TclLogCommandInfo(interp, script, command, length, NULL, NULL);